@@ -549,7 +549,11 @@ class UpdateWorkflow(Workflow):
                 )
             else:
                 dserv = DownloadClient()
-            proxy = self.bank.config.get('micro.biomaj.proxy')
+
+            proxy = self.bank.config.get('micro.biomaj.proxy.download')
+            if not proxy:
+                proxy = self.bank.config.get('micro.biomaj.proxy')
+
             session = dserv.create_session(self.name, proxy)
             logging.info("Workflow:wf_release:DownloadSession:" + str(session))
 
@@ -586,13 +590,6 @@ class UpdateWorkflow(Workflow):
 
             params = None
             keys = cf.get('url.params')
-            if keys is not None:
-                params = {}
-                keys = keys.split(',')
-                for key in keys:
-                    param = cf.get(key.strip() + '.value')
-                    params[key.strip()] = param.strip()
-
             credentials = cf.get('server.credentials')
             if cf.get('release.credentials') is not None:
                 credentials = cf.get('release.credentials')
@@ -600,12 +597,32 @@ class UpdateWorkflow(Workflow):
             save_as = None
             method = 'GET'
             if protocol == 'directhttp' or protocol == 'directhttps' or protocol == 'directftp':
+                keys = cf.get('url.params')
+                if keys is not None:
+                    params = {}
+                    keys = keys.split(',')
+                    for key in keys:
+                        param = cf.get(key.strip() + '.value')
+                        params[key.strip()] = param.strip()
+
                 save_as = cf.get('release.file')
                 remotes = [remote_dir]
                 remote_dir = '/'
                 method = cf.get('url.method')
                 if cf.get('release.url.method') is not None:
                     method = cf.get('release.url.method')
+            # add params for irods to get port, password, user, zone
+            if protocol == 'irods':
+                keys = None
+                keys = str(str(cf.get('irods.user')) + ',' + str(cf.get('irods.password')) + ',' + str(cf.get('irods.port')) + ',' + str(cf.get('irods.protocol')))
+                if keys is not None:
+                    params = {}
+                    keys = str(keys).split(',')
+                    params['user'] = str(cf.get('irods.user')).strip()
+                    params['password'] = str(cf.get('irods.password')).strip()
+                    params['port'] = str(cf.get('irods.port')).strip()
+                    params['protocol'] = str(cf.get('irods.protocol')).strip()
+                    params['zone'] = str(cf.get('irods.zone')).strip()
 
             release_downloader = dserv.get_handler(
                 protocol,
@@ -938,7 +955,10 @@ class UpdateWorkflow(Workflow):
         if pool_size:
             dserv.set_queue_size(int(pool_size))
 
-        proxy = self.bank.config.get('micro.biomaj.proxy')
+        proxy = self.bank.config.get('micro.biomaj.proxy.download')
+        if not proxy:
+            proxy = self.bank.config.get('micro.biomaj.proxy')
+
         session = dserv.create_session(self.name, proxy)
         logging.info("Workflow:wf_download:DownloadSession:" + str(session))
 
@@ -1055,14 +1075,6 @@ class UpdateWorkflow(Workflow):
             server = cf.get('server')
 
             params = None
-            keys = cf.get('url.params')
-            if keys is not None:
-                params = {}
-                keys = keys.split(',')
-                for key in keys:
-                    param = cf.get(key.strip() + '.value')
-                    params[key.strip()] = param.strip()
-
             method = cf.get('url.method')
             if method is None:
                 method = 'GET'
@@ -1071,8 +1083,28 @@ class UpdateWorkflow(Workflow):
 
             remote_dir = cf.get('remote.dir')
             if protocol == 'directhttp' or protocol == 'directhttps' or protocol == 'directftp':
+                keys = cf.get('url.params')
+                if keys is not None:
+                    params = {}
+                    keys = keys.split(',')
+                    for key in keys:
+                        param = cf.get(key.strip() + '.value')
+                        params[key.strip()] = param.strip()
+
                 remotes = [cf.get('remote.dir')[:-1]]
                 remote_dir = '/'
+            # add params for irods to get port, password, user, zone
+            if protocol == 'irods':
+                keys = None
+                keys = str(str(cf.get('irods.user')) + ',' + str(cf.get('irods.password')) + ',' + str(cf.get('irods.port')) + ',' + str(cf.get('irods.protocol')))
+                if keys is not None:
+                    params = {}
+                    keys = str(keys).split(',')
+                    params['user'] = str(cf.get('irods.user')).strip()
+                    params['password'] = str(cf.get('irods.password')).strip()
+                    params['port'] = str(cf.get('irods.port')).strip()
+                    params['protocol'] = str(cf.get('irods.protocol')).strip()
+                    params['zone'] = str(cf.get('irods.zone')).strip()
 
             save_as = cf.get('target.name')
 
@@ -1311,7 +1343,10 @@ class UpdateWorkflow(Workflow):
         if pool_size:
             dserv.set_queue_size(int(pool_size))
 
-        proxy = self.bank.config.get('micro.biomaj.proxy')
+        proxy = self.bank.config.get('micro.biomaj.proxy.download')
+        if not proxy:
+            proxy = self.bank.config.get('micro.biomaj.proxy')
+
         session = dserv.create_session(self.name, proxy)
         logging.info("Workflow:wf_download:DownloadSession:" + str(session))
 
@@ -1636,14 +1671,17 @@ class UpdateWorkflow(Workflow):
         nb_prod = len(self.bank.bank['production'])
         # save session during delete workflow
         keep_session = self.bank.session
-
+        old_deleted = False
         if nb_prod > keep:
             for prod in self.bank.bank['production']:
                 if prod['release'] == keep_session.get('release'):
+                    logging.info('Release %s tagged as keep_session, skipping' % (str(prod['release'])))
                     continue
                 if 'freeze' in prod and prod['freeze']:
+                    logging.info('Release %s tagged as freezed, skipping' % (str(prod['release'])))
                     continue
                 if self.bank.bank['current'] == prod['session']:
+                    logging.info('Release %s tagged as current, skipping' % (str(prod['release'])))
                     continue
                 if nb_prod - keep > 0:
                     nb_prod -= 1
@@ -1670,10 +1708,14 @@ class UpdateWorkflow(Workflow):
                     res = self.bank.start_remove(session)
                     if not res:
                         logging.error('Workflow:wf_delete_old:ErrorDelete:' + prod['release'])
+                    else:
+                        old_deleted = True
                 else:
                     break
         # Set session back
         self.bank.session = keep_session
+        if old_deleted:
+            self.bank.session._session['remove'] = True
 
         return True
 
